Scripts, tests and other modules — polyfemos 0.3.29 documentation

# Scripts, tests and other modules

`polyfemos.almanac.ordinal` | Contains `Ordinal` class
`polyfemos.almanac.timer` | Timing utility classes for debugging
`polyfemos.almanac.utils` | Collection of miscellanous date functions
`polyfemos.data.outlierremover` | A function collection to remove outliers from the data
`polyfemos.data.statistics` | Functions for retrieving statistical info about the data
`polyfemos.data.utils` | Miscellanous data manipulation functions
`polyfemos.parser.filepathparser` | Functions to parse filepaths from strings
`polyfemos.parser.functionparser` | Functions to parse filepaths from strings following the internal function syntax
`polyfemos.parser.resources` | Contains all commands, special characters and reserved variables for ‘*.conf’ files
`polyfemos.parser.typeoperator` | Functions representing types used internally in polyfemos
`polyfemos.scripts.check_output_files` | A command line script to check polyfemos output files.
`polyfemos.scripts.devserver` | A command line script to create polyfemos development server, call the script in folder where ‘conf/front/global_config.yml’ is available.
`polyfemos.scripts.render_web_templates` | A script to replace values in web templates with values defined in YAML configuration files.
`polyfemos.scripts.test_front_paths` | Test polyfemos frontend paths
`polyfemos.scripts.sohemailer` | A script for sending state of health alerts via email
`polyfemos.tests.test_python_packages` | Checks if all packages required by polyfemos are installed.
`polyfemos.util.coordinator` | Coordinate transformation functions
`polyfemos.util.fileutils` | Functions for reading and writing files.
`polyfemos.util.messenger` | Functions for printing and debugging
`polyfemos.util.randomizer` | A small module for generating ascii secret keys.